%global pypi_name dnspython
%global py_package_name dns
%global rctag %{nil}
%global __python3 /usr/bin/python3.9

%if 0%{?rhel}
%bcond_with trio
%bcond_with curio
%bcond_with doh
%else
%bcond_without trio
%bcond_without curio
%bcond_without doh
%endif

Name:           python39-%{py_package_name}
Version:        2.2.1
Release:        1%{?dist}
Summary:        DNS toolkit for Python

# The entire package is licensed with both licenses, see LICENSE file
License:        ISC and MIT
URL:            http://www.dnspython.org

Source0:        %pypi_source
BuildArch:      noarch

BuildRequires:  python39-devel
BuildRequires:  python39-setuptools
BuildRequires:  python39-cryptography
%if %{with trio}
BuildRequires:  python39-trio
%endif
%if %{with curio}
BuildRequires:  python39-curio
%endif
%if %{with trio} || %{with curio}
BuildRequires:  python39-sniffio
%endif
%if %{with doh}
BuildRequires:  python39-requests
BuildRequires:  python39-requests-toolbelt
%endif
BuildRequires:  python39-idna
BuildRequires:  python39-pytest
BuildRequires:  python39-setuptools_scm
BuildRequires:  python39-wheel

%global _description %{expand:
dnspython is a DNS toolkit for Python. It supports almost all record
types. It can be used for queries, zone transfers, and dynamic
updates. It supports TSIG authenticated messages and EDNS0.

dnspython provides both high and low level access to DNS. The high
level classes perform queries for data of a given name, type, and
class, and return an answer set. The low level classes allow direct
manipulation of DNS zones, messages, names, and records.
}

%description %_description
%{?python_provide:%python_provide python39-%{py_package_name}}

%prep
%autosetup -p1 -n %{pypi_name}-%{version}%{rctag}

# strip exec permissions so that we don't pick up dependencies from docs
find examples -type f | xargs chmod a-x

%build
%py3_build

%install
%py3_install

%check
pytest-3.9 || :

%files
%license LICENSE
%doc README.md examples
%{?python_extras_subpkg:
%pycached %exclude %{python3_sitelib}/dns/_trio_backend.py
%pycached %exclude %{python3_sitelib}/dns/_curio_backend.py
}
%{python3_sitelib}/%{py_package_name}
%{python3_sitelib}/%{pypi_name}-*.egg-info

%{?python_extras_subpkg:
%python_extras_subpkg -n python39-dns -i %{python3_sitelib}/*.egg-info dnssec idna

%if %{with doh}
%python_extras_subpkg -n python39-dns -i %{python3_sitelib}/*.egg-info doh
%endif

%if %{with trio}
%python_extras_subpkg -n python39-dns -i %{python3_sitelib}/*.egg-info trio
%pycached %{python3_sitelib}/dns/_trio_backend.py
%endif

%if %{with curio}
%python_extras_subpkg -n python39-dns -i %{python3_sitelib}/*.egg-info curio
%pycached %{python3_sitelib}/dns/_curio_backend.py
%endif

# end of python_extras_subpkg
}

%changelog
* Wed Sep 28 2022 Orion Poplawski <orion@nwra.com> - 2.2.1-1
- EPEL package for Python 3.9
